diff --git a/gramps/plugins/tool/findloop.glade b/gramps/plugins/tool/findloop.glade
index 00a986b52..3fc52ec70 100644
--- a/gramps/plugins/tool/findloop.glade
+++ b/gramps/plugins/tool/findloop.glade
@@ -27,7 +27,7 @@
True
False
True
-
+
False
diff --git a/gramps/plugins/tool/findloop.py b/gramps/plugins/tool/findloop.py
index 3b6d76e24..e71ce39f5 100644
--- a/gramps/plugins/tool/findloop.py
+++ b/gramps/plugins/tool/findloop.py
@@ -56,7 +56,7 @@ from gramps.gui.editors import EditFamily
#
#-------------------------------------------------------------------------
WIKI_HELP_PAGE = '%s_-_Tools' % URL_MANUAL_PAGE
-WIKI_HELP_SEC = _('manual|Find_possible_loop_in_the_database')
+WIKI_HELP_SEC = _('manual|Find_database_loop')
#------------------------------------------------------------------------
#
@@ -68,7 +68,7 @@ class FindLoop(ManagedWindow) :
def __init__(self, dbstate, user, options_class, name, callback=None):
uistate = user.uistate
- self.title = _('Find possible loop')
+ self.title = _('Find database loop')
ManagedWindow.__init__(self, uistate, [], self.__class__)
self.dbstate = dbstate
self.uistate = uistate
@@ -202,6 +202,9 @@ class FindLoop(ManagedWindow) :
"""Display the relevant portion of GRAMPS manual"""
display_help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
+ def close(self, *obj):
+ ManagedWindow.close(self,*obj)
+
#------------------------------------------------------------------------
#
# FindLoopOptions
diff --git a/gramps/plugins/tool/tools.gpr.py b/gramps/plugins/tool/tools.gpr.py
index 4262ea458..98a86ce10 100644
--- a/gramps/plugins/tool/tools.gpr.py
+++ b/gramps/plugins/tool/tools.gpr.py
@@ -476,13 +476,13 @@ tool_modes = [TOOL_MODE_GUI]
#------------------------------------------------------------------------
#
# Find Possible Loop
#
#------------------------------------------------------------------------
register(TOOL,
id = 'loop',
-name = _("Find Possible Loop"),
+name = _("Find database loop"),
description = _("Searches the entire database, looking for "
"a possible loop."),
version = '1.0',
@@ -476,13 +476,13 @@ tool_modes = [TOOL_MODE_GUI]
#------------------------------------------------------------------------
#
-# Find Possible Loop
+# Find database Loop
#
#------------------------------------------------------------------------